@@ -152,10 +152,6 @@ class AbstractSeriesAggregator(ABC):
 
         self._supports_dtype(s)
 
-        # convert the bool values to uint8 (as we will display them on a y-axis)
-        if str(s.dtype) == "bool":
-            s = s.astype("uint8")
-
         if len(s) > n_out:
             # More samples that n_out -> perform data aggregation
             s = self._aggregate(s, n_out=n_out)
