@@ -457,6 +457,7 @@ class AbstractFigureAggregator(BaseFigure, ABC):
 
         """
         from ..registering import _get_plotly_constr  # To avoid ImportError
+
         return _get_plotly_constr(constr)
 
     @staticmethod
@@ -679,7 +680,14 @@ class AbstractFigureAggregator(BaseFigure, ABC):
             # transform it to type string as such it will be sent as categorical data
             # to the downsampling algorithm
             if hf_y.dtype == "object":
-                hf_y = hf_y.astype("str")
+                # But first, we try to parse to a numeric dtype (as this is the
+                # behavior that plotly supports)
+                # Note that a bool array of type object will remain a bool array (and 
+                # not will be transformed to an array of ints (0, 1))
+                try:
+                    hf_y = pd.to_numeric(hf_y, errors="raise")
+                except:
+                    hf_y = hf_y.astype("str")
 
             # orjson encoding doesn't like to encode with uint8 & uint16 dtype
             if str(hf_y.dtype) in ["uint8", "uint16"]:
@@ -1097,10 +1105,7 @@ class AbstractFigureAggregator(BaseFigure, ABC):
 
         """
         hf_data_cp = {
-            uid: {
-                k: hf_dict[k]
-                for k in set(hf_dict.keys())
-            }
+            uid: {k: hf_dict[k] for k in set(hf_dict.keys())}
             for uid, hf_dict in hf_data.items()
         }
 
